summaryrefslogtreecommitdiffstats
path: root/scd/app-nks.c
diff options
context:
space:
mode:
authorDaniel Kahn Gillmor <dkg@fifthhorseman.net>2020-02-18 15:34:42 +0100
committerDaniel Kahn Gillmor <dkg@fifthhorseman.net>2020-02-19 00:07:46 +0100
commit0904b8ef348a52335c378bee6dc90a978885d66f (patch)
treeaff1ea1d709d45724af04b7e985bca1284bdb2a0 /scd/app-nks.c
parentdoc: Correction of typo in documentation of KEY_CONSIDERED (diff)
downloadgnupg2-0904b8ef348a52335c378bee6dc90a978885d66f.tar.xz
gnupg2-0904b8ef348a52335c378bee6dc90a978885d66f.zip
Spelling cleanup.
No functional changes, just fixing minor spelling issues. --- Most of these were identified from the command line by running: codespell \ --ignore-words-list fpr,stati,keyserver,keyservers,asign,cas,iff,ifset \ --skip '*.po,ChangeLog*,help.*.txt,*.jpg,*.eps,*.pdf,*.png,*.gpg,*.asc' \ doc g13 g10 kbx agent artwork scd tests tools am common dirmngr sm \ NEWS README README.maint TODO Signed-off-by: Daniel Kahn Gillmor <dkg@fifthhorseman.net>
Diffstat (limited to 'scd/app-nks.c')
-rw-r--r--scd/app-nks.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/scd/app-nks.c b/scd/app-nks.c
index bdf065145..efc11296a 100644
--- a/scd/app-nks.c
+++ b/scd/app-nks.c
@@ -255,7 +255,7 @@ keygripstr_from_pk_file (app_t app, int fid, char *r_gripstr)
-1 = Error retrieving the data,
-2 = No such PIN,
-3 = PIN blocked,
- -4 = NullPIN activ,
+ -4 = NullPIN active,
n >= 0 = Number of verification attempts left. */
static int
get_chv_status (app_t app, int sigg, int pwid)
@@ -287,7 +287,7 @@ get_chv_status (app_t app, int sigg, int pwid)
else if (sw == 0x6983)
rc = -3; /* PIN is blocked. */
else if (sw == 0x6985)
- rc = -4; /* NullPIN is activ. */
+ rc = -4; /* NullPIN is active. */
else if ((sw & 0xfff0) == 0x63C0)
rc = (sw & 0x000f); /* PIN has N tries left. */
else